==> isis-1.16.2-source-release.zip: isis-1.16.2/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/actions/notcontributed/NotContributedFacetAbstract.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */

package org.apache.isis.core.metamodel.facets.actions.notcontributed;

import org.apache.isis.applib.annotation.NotContributed.As;
import org.apache.isis.core.metamodel.facetapi.Facet;
import org.apache.isis.core.metamodel.facetapi.FacetAbstract;
import org.apache.isis.core.metamodel.facetapi.FacetHolder;

public abstract class NotContributedFacetAbstract extends FacetAbstract implements NotContributedFacet {

    private final As as;

    public static Class<? extends Facet> type() {
        return NotContributedFacet.class;
    }

    public NotContributedFacetAbstract(final As as, final FacetHolder holder) {
        this(as, holder, Derivation.NOT_DERIVED);
    }

    public NotContributedFacetAbstract(final As as, final FacetHolder holder, final Derivation derivation) {
        super(type(), holder, derivation);
        this.as = as;
    }

    @Override
    public As value() {
        return as;
    }

    @Override
    public boolean toActions() {
        return value() == As.EITHER || value() == As.ACTION;
    }

    @Override
    public boolean toAssociations() {
        return value() == As.EITHER || value() == As.ASSOCIATION;
    }

}

==> isis-1.17.0-source-release.zip: isis-1.17.0/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/actions/notcontributed/NotContributedFacetAbstract.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */

package org.apache.isis.core.metamodel.facets.actions.notcontributed;

import java.util.Map;

import org.apache.isis.applib.annotation.NotContributed.As;
import org.apache.isis.core.metamodel.facetapi.Facet;
import org.apache.isis.core.metamodel.facetapi.FacetAbstract;
import org.apache.isis.core.metamodel.facetapi.FacetHolder;

public abstract class NotContributedFacetAbstract extends FacetAbstract implements NotContributedFacet {

    private final As as;

    public static Class<? extends Facet> type() {
        return NotContributedFacet.class;
    }

    public NotContributedFacetAbstract(final As as, final FacetHolder holder) {
        this(as, holder, Derivation.NOT_DERIVED);
    }

    public NotContributedFacetAbstract(final As as, final FacetHolder holder, final Derivation derivation) {
        super(type(), holder, derivation);
        this.as = as;
    }

    @Override
    public As value() {
        return as;
    }

    @Override
    public boolean toActions() {
        return value() == As.EITHER || value() == As.ACTION;
    }

    @Override
    public boolean toAssociations() {
        return value() == As.EITHER || value() == As.ASSOCIATION;
    }

    @Override public void appendAttributesTo(final Map<String, Object> attributeMap) {
        super.appendAttributesTo(attributeMap);
        attributeMap.put("as", as);
    }

}
